==> org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.source_0.9.0.201704060416.jar: org/eclipse/papyrusrt/umlrt/tooling/views/codesnippet/tabs/TransitionEffectTab.java <==
/*******************************************************************************
 * Copyright (c) 2017 Zeligsoft (2009) Limited and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Young-Soo Roh - Initial API and implementation
 *******************************************************************************/
package org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.tabs;

import org.eclipse.core.databinding.observable.IObservable;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.papyrus.uml.properties.expression.ExpressionList;
import org.eclipse.papyrus.uml.properties.expression.ExpressionList.Expression;
import org.eclipse.papyrus.uml.properties.modelelement.UMLModelElement;
import org.eclipse.papyrusrt.umlrt.core.utils.StateMachineUtils;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTFactory;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTInheritanceKind;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTOpaqueBehavior;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTTransition;
import org.eclipse.swt.graphics.Image;
import org.eclipse.uml2.uml.Behavior;
import org.eclipse.uml2.uml.StateMachine;
import org.eclipse.uml2.uml.Transition;

/**
 * Code snippet tab for transition effect.
 * 
 * @author ysroh
 *
 */
public class TransitionEffectTab extends AbstractCodeSnippetTab {

	/**
	 * 
	 * Constructor.
	 *
	 */
	public TransitionEffectTab() {
	}

	@Override
	public String getTitle() {
		return "Effect";
	}

	@Override
	public Image getImage() {
		UMLRTInheritanceKind inheritance = UMLRTInheritanceKind.NONE;

		if (shouldShowThisTab(input)) {
			Transition transition = (Transition) input;
			Behavior effect = transition.getEffect();
			if (effect != null) {
				return labelProvider.getImage(effect);
			}
		}
		return org.eclipse.papyrusrt.umlrt.tooling.diagram.statemachine.Activator.getImage(
				org.eclipse.papyrusrt.umlrt.tooling.diagram.statemachine.Activator.getEffectSmallKey(inheritance));
	}

	@Override
	public boolean shouldShowThisTab(EObject context) {
		if (context instanceof Transition) {
			Transition transition = (Transition) context;
			StateMachine sm = transition.containingStateMachine();
			return StateMachineUtils.isRTStateMachine(sm);
		}
		return false;
	}

	@Override
	protected IObservable getFeatureObservable() {
		UMLModelElement modelElement = new UMLModelElement(input);
		return modelElement.doGetObservable("effect");
	}

	@Override
	protected ExpressionList getExpressionObservableList() {
		Transition transition = (Transition) input;
		return getExpressionList(transition.getEffect());
	}

	@Override
	protected void saveInitialExpression(Expression ex) {
		UMLRTTransition transition = UMLRTFactory.createTransition((Transition) input);
		UMLRTOpaqueBehavior ob = transition.createEffect(ex.getLanguage(), ex.getBody());
		ob.setName(getTitle());
	}
}

==> org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.source_0.9.0.201704270417.jar: org/eclipse/papyrusrt/umlrt/tooling/views/codesnippet/tabs/TransitionEffectTab.java <==
/*******************************************************************************
 * Copyright (c) 2017 Zeligsoft (2009) Limited and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Young-Soo Roh - Initial API and implementation
 *******************************************************************************/
package org.eclipse.papyrusrt.umlrt.tooling.views.codesnippet.tabs;

import org.eclipse.core.databinding.observable.IObservable;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.papyrus.uml.properties.expression.ExpressionList;
import org.eclipse.papyrus.uml.properties.expression.ExpressionList.Expression;
import org.eclipse.papyrusrt.umlrt.core.utils.StateMachineUtils;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTFactory;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTInheritanceKind;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTOpaqueBehavior;
import org.eclipse.papyrusrt.umlrt.uml.UMLRTTransition;
import org.eclipse.swt.graphics.Image;
import org.eclipse.uml2.uml.Behavior;
import org.eclipse.uml2.uml.StateMachine;
import org.eclipse.uml2.uml.Transition;

/**
 * Code snippet tab for transition effect.
 * 
 * @author ysroh
 *
 */
public class TransitionEffectTab extends AbstractCodeSnippetTab {

	/**
	 * 
	 * Constructor.
	 *
	 */
	public TransitionEffectTab() {
	}

	@Override
	public String getTitle() {
		return "Effect";
	}

	@Override
	public Image getImage() {
		UMLRTInheritanceKind inheritance = UMLRTInheritanceKind.NONE;

		if (shouldShowThisTab(input)) {
			Transition transition = (Transition) input;
			Behavior effect = transition.getEffect();
			if (effect != null) {
				return getLabelProvider().getImage(effect);
			}
		}
		return org.eclipse.papyrusrt.umlrt.tooling.diagram.statemachine.Activator.getImage(
				org.eclipse.papyrusrt.umlrt.tooling.diagram.statemachine.Activator.getEffectSmallKey(inheritance));
	}

	@Override
	public boolean shouldShowThisTab(EObject context) {
		if (context instanceof Transition) {
			Transition transition = (Transition) context;
			StateMachine sm = transition.containingStateMachine();
			return StateMachineUtils.isRTStateMachine(sm);
		}
		return false;
	}

	@Override
	protected IObservable getFeatureObservable() {
		if (meForFeatureObservable == null) {
			meForFeatureObservable = rtModelFactory.createFromSource(input, null);
		}
		return meForFeatureObservable.getObservable("effect");
	}

	@Override
	protected ExpressionList getExpressionObservableList() {
		Transition transition = (Transition) input;
		return getExpressionList(transition.getEffect());
	}

	@Override
	protected void saveInitialExpression(Expression ex) {
		UMLRTTransition transition = UMLRTFactory.createTransition((Transition) input);
		UMLRTOpaqueBehavior ob = transition.createEffect(ex.getLanguage(), ex.getBody());
		ob.setName(getTitle());
	}

	@Override
	protected IObservable getSpecificationObservable() {
		return getSpecificationObservable(((Transition) input).getEffect());
	}
}
